@@ -1,7 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2007 Jean-Baptiste Mardelle <jb@kdenlive.org>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #ifndef RENDERJOB_H
@@ -72,7 +72,7 @@ private:
 #else
     void initKdenliveDbusInterface();
 #endif
-    void sendFinish(int status, QString error);
+    void sendFinish(int status, const QString &error);
     void sendProgress();
 
 signals:
