@@ -15,10 +15,23 @@
 #include <KMessageBox>
 #include <QPushButton>
 
+// TODO replace this by std::gcd ones why require C++17 or greater
+static int gcd(int a, int b)
+{
+    for (;;)
+    {
+        if (a == 0) return b;
+        b %= a;
+        if (b == 0) return a;
+        a %= b;
+    }
+}
+
 RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *preset, Mode mode)
     : QDialog(parent)
-    , m_saveName()
+    , m_saveName(preset ? preset->name() : "")
     , m_monitor(nullptr)
+    , m_fixedResRatio(1.)
 {
     setupUi(this);
 
@@ -64,6 +77,10 @@ RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *prese
                           QStringLiteral("channels")
                       });
 
+    // TODO: implement colorspace
+    colorspaceCombo->hide();
+    colorspaceLabel->hide();
+
     formatCombo->addItems(RenderPresetRepository::supportedFormats());
     vCodecCombo->addItems(RenderPresetRepository::vcodecs());
     aCodecCombo->addItems(RenderPresetRepository::acodecs());
@@ -80,40 +97,88 @@ RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *prese
     QValidator *validator = new QIntValidator(this);
     audioSampleRate->setValidator(validator);
 
-    vRateControlCombo->addItem(i18n("Average Bitrate"));
-    vRateControlCombo->addItem(i18n("CBR – Constant Bitrate"));
-    vRateControlCombo->addItem(i18n("VBR – Variable Bitrate"));
-    vRateControlCombo->addItem(i18n("Contrained VBR"));
+    // Add some common pixel aspect ratios:
+    // The following code works, because setting a yet
+    // unknown ratio will add it to the combo box.
+    setPixelAspectRatio(1, 1);
+    setPixelAspectRatio(10, 11);
+    setPixelAspectRatio(12, 11);
+    setPixelAspectRatio(59, 54);
+    setPixelAspectRatio(4, 3);
+    setPixelAspectRatio(64, 45);
+    setPixelAspectRatio(11, 9);
+    setPixelAspectRatio(118, 81);
 
     connect(vRateControlCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, [this](int index) {
         switch (index) {
             case RenderPresetModel::RateControl::Average:
                 default_vbitrate->setEnabled(true);
+                default_vbitrate_label->setEnabled(true);
                 default_vquality->setEnabled(false);
+                vquality_label->setEnabled(false);
                 vBuffer->setEnabled(false);
+                vBuffer_label->setEnabled(false);
                 break;
             case RenderPresetModel::RateControl::Constant:
                 default_vbitrate->setEnabled(true);
+                default_vbitrate_label->setEnabled(true);
                 default_vquality->setEnabled(false);
+                vquality_label->setEnabled(false);
                 vBuffer->setEnabled(true);
+                vBuffer_label->setEnabled(true);
                 break;
             case RenderPresetModel::RateControl::Constrained:
                 default_vbitrate->setEnabled(true);
+                default_vbitrate_label->setEnabled(true);
                 default_vquality->setEnabled(true);
+                vquality_label->setEnabled(true);
                 vBuffer->setEnabled(true);
+                vBuffer_label->setEnabled(true);
                 break;
             case RenderPresetModel::RateControl::Quality:
                 default_vbitrate->setEnabled(false);
+                default_vbitrate_label->setEnabled(false);
                 default_vquality->setEnabled(true);
+                vquality_label->setEnabled(true);
                 vBuffer->setEnabled(false);
+                vBuffer_label->setEnabled(false);
                 break;
         };
         slotUpdateParams();
     });
 
+    vRateControlCombo->addItem(i18n("Average Bitrate"));
+    vRateControlCombo->addItem(i18n("CBR – Constant Bitrate"));
+    vRateControlCombo->addItem(i18n("VBR – Variable Bitrate"));
+    vRateControlCombo->addItem(i18n("Contrained VBR"));
+
+    connect(scanningCombo, &QComboBox::currentTextChanged, this, [&](){
+        fieldOrderCombo->setEnabled(scanningCombo->currentIndex() != 1);
+        fieldOrderLabel->setEnabled(scanningCombo->currentIndex() != 1);
+        slotUpdateParams();
+    });
+    connect(gopSpinner, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, [&] (int value) {
+        fixedGop->setEnabled(value > 1);
+        bFramesSpinner->setEnabled(value > 1);
+        bFramesLabel->setEnabled(value > 1);
+        if (value <= 1) {
+            fixedGop->blockSignals(true);
+            fixedGop->setChecked(false);
+            fixedGop->blockSignals(false);
+            bFramesSpinner->blockSignals(true);
+            bFramesSpinner->setValue(-1);
+            bFramesSpinner->blockSignals(false);
+        } else {
+            bFramesSpinner->setMaximum(value - 1);
+        }
+        slotUpdateParams();
+    });
+
     groupName->addItems(RenderPresetRepository::get()->groupNames());
 
     std::unique_ptr<ProfileModel> &projectProfile = pCore->getCurrentProfile();
+    int parNum = projectProfile->sample_aspect_num();
+    int parDen = projectProfile->sample_aspect_den();
     if (preset) {
         groupName->setCurrentText(preset->groupName());
         if (mode != Mode::New) {
@@ -174,17 +239,14 @@ RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *prese
         QString sampAsp = preset->getParam(QStringLiteral("aspect"));
 
         if (!(sampAspNum.isEmpty() && sampAspDen.isEmpty())) {
-            pixelAspectNum->setValue(sampAspNum.toInt());
-            pixelAspectDen->setValue(sampAspDen.toInt());
+            parNum = sampAspNum.toInt();
+            parDen = sampAspDen.toInt();
         } else if (!sampAsp.isEmpty()) {
             QStringList list = sampAsp.split(QStringLiteral("/"));
             if (list.count() == 2) {
-                pixelAspectNum->setValue(list.at(0).toInt());
-                pixelAspectDen->setValue(list.at(1).toInt());
+                parNum = list.at(0).toInt();
+                parDen = list.at(1).toInt();
             }
-        } else {
-            pixelAspectNum->setValue(projectProfile->sample_aspect_num());
-            pixelAspectDen->setValue(projectProfile->sample_aspect_den());
         }
 
         if (preset->hasParam(QStringLiteral("display_aspect_num"))
@@ -267,13 +329,15 @@ RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *prese
         resWidth->setValue(projectProfile->width());
         framerateNum->setValue(projectProfile->frame_rate_num());
         framerateDen->setValue(projectProfile->frame_rate_den());
-        pixelAspectNum->setValue(projectProfile->sample_aspect_num());
-        pixelAspectDen->setValue(projectProfile->sample_aspect_den());
+        parNum = projectProfile->sample_aspect_num();
+        parDen = projectProfile->sample_aspect_den();
         displayAspectNum->setValue(projectProfile->display_aspect_num());
         displayAspectDen->setValue(projectProfile->display_aspect_den());
         scanningCombo->setCurrentIndex(projectProfile->progressive() ? 1 : 0);
     }
 
+    setPixelAspectRatio(parNum, parDen);
+
     if (groupName->currentText().isEmpty()) {
         groupName->setCurrentText(i18nc("Group Name", "Custom"));
     }
@@ -311,8 +375,8 @@ RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *prese
                                                                            QString::number(aQuality->value()),
                                                                            speeds_list_str));
 
-        m_saveName = RenderPresetRepository::get()->savePreset(newPreset.get());
-        if ((mode == Mode::Edit) && (oldName != m_saveName)) {
+        m_saveName = RenderPresetRepository::get()->savePreset(newPreset.get(), mode == Mode::Edit);
+        if ((mode == Mode::Edit) && !m_saveName.isEmpty() && (oldName != m_saveName)) {
             RenderPresetRepository::get()->deletePreset(oldName);
         }
         accept();
@@ -320,32 +384,37 @@ RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *prese
 
     connect(formatCombo, &QComboBox::currentTextChanged, this, &RenderPresetDialog::slotUpdateParams);
     connect(vCodecCombo, &QComboBox::currentTextChanged, this, &RenderPresetDialog::slotUpdateParams);
-    connect(scanningCombo, &QComboBox::currentTextChanged, this, [&](){
-        fieldOrderCombo->setEnabled(scanningCombo->currentIndex() != 1);
-        slotUpdateParams();
-    });
+
     connect(fieldOrderCombo, &QComboBox::currentTextChanged, this, &RenderPresetDialog::slotUpdateParams);
     connect(aCodecCombo, &QComboBox::currentTextChanged, this, &RenderPresetDialog::slotUpdateParams);
-    connect(resWidth, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderPresetDialog::slotUpdateParams);
-    connect(resHeight, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderPresetDialog::slotUpdateParams);
-    connect(pixelAspectNum, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, [&](int value){
-        if (value == 0) {
-            pixelAspectDen->blockSignals(true);
-            pixelAspectDen->setValue(0);
-            pixelAspectDen->blockSignals(false);
-        }
-        slotUpdateParams();
+    connect(linkResoultion, &QToolButton::clicked, this, [&](){
+        m_fixedResRatio = double(resWidth->value()) / double(resHeight->value());
     });
-    connect(pixelAspectDen, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, [&](int value){
-        if (value == 0) {
-            pixelAspectNum->blockSignals(true);
-            pixelAspectNum->setValue(0);
-            pixelAspectNum->blockSignals(false);
+    connect(resWidth, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, [&](int value){
+        if (linkResoultion->isChecked()) {
+            resHeight->blockSignals(true);
+            resHeight->setValue(qRound(value / m_fixedResRatio));
+            resHeight->blockSignals(false);
         }
-        slotUpdateParams();
+        updateDisplayAspectRatio();
     });
-    connect(displayAspectNum, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderPresetDialog::slotUpdateParams);
-    connect(displayAspectDen, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderPresetDialog::slotUpdateParams);
+    connect(resHeight, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, [&](int value){
+        if (linkResoultion->isChecked()) {
+            resWidth->blockSignals(true);
+            resWidth->setValue(qRound(value * m_fixedResRatio));
+            resWidth->blockSignals(false);
+        }
+        updateDisplayAspectRatio();
+    });
+    connect(parCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &RenderPresetDialog::updateDisplayAspectRatio);
+    auto update_par = [&]() {
+        int parNum = displayAspectNum->value() * resHeight->value();
+        int parDen = displayAspectDen->value() * resWidth->value();
+        setPixelAspectRatio(parNum, parDen);
+        slotUpdateParams();
+    };
+    connect(displayAspectNum, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, update_par);
+    connect(displayAspectDen, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, update_par);
     connect(framerateNum, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, [&](int value){
         if (value == 0) {
             framerateDen->blockSignals(true);
@@ -363,7 +432,6 @@ RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *prese
         slotUpdateParams();
     });
     connect(fixedGop, &QCheckBox::stateChanged, this, &RenderPresetDialog::slotUpdateParams);
-    connect(gopSpinner, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderPresetDialog::slotUpdateParams);
     connect(bFramesSpinner, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &RenderPresetDialog::slotUpdateParams);
     connect(additionalParams, &QPlainTextEdit::textChanged, this, &RenderPresetDialog::slotUpdateParams);
 
@@ -373,6 +441,7 @@ RenderPresetDialog::RenderPresetDialog(QWidget *parent, RenderPresetModel *prese
     connect(audioChannels, &QComboBox::currentTextChanged, this, &RenderPresetDialog::slotUpdateParams);
     connect(audioSampleRate, &QComboBox::currentTextChanged, this, &RenderPresetDialog::slotUpdateParams);
 
+    linkResoultion->setChecked(true);
     slotUpdateParams();
     // TODO
     if (false && m_monitor == nullptr) {
@@ -409,10 +478,11 @@ void RenderPresetDialog::slotUpdateParams() {
     if (resHeight->value() > 0) {
         params.append(QStringLiteral("height=%1").arg(resHeight->value()));
     }
-    if (pixelAspectNum->value() > 0 && pixelAspectDen->value() > 0) {
+    QStringList par = parCombo->currentData().toString().split(QStringLiteral(":"));
+    if (par.length() >= 2 && par.at(0).toInt() > 0 && par.at(1).toInt() > 0) {
         params.append(QStringLiteral("sample_aspect_num=%1 sample_aspect_den=%2")
-                      .arg(pixelAspectNum->value())
-                      .arg(pixelAspectDen->value()));
+                      .arg(par.at(0).toInt())
+                      .arg(par.at(1).toInt()));
     }
     if (displayAspectNum->value() > 0 && displayAspectDen->value() > 0 ) {
         params.append(QStringLiteral("display_aspect_num=%1 display_aspect_den=%2")
@@ -456,7 +526,7 @@ void RenderPresetDialog::slotUpdateParams() {
             break;
             }
         }
-        if (fixedGop->isChecked()) {
+        if (fixedGop->isEnabled() && fixedGop->isChecked()) {
             params.append(QStringLiteral("sc_threshold=0"));
         }
     } else if (vcodec.contains("nvenc")) {
@@ -489,7 +559,7 @@ void RenderPresetDialog::slotUpdateParams() {
         /*if (ui->dualPassCheckbox->isChecked())
             setIfNotSet(p, "v2pass", 1);
         */
-        if (fixedGop->isChecked()) {
+        if (fixedGop->isEnabled() && fixedGop->isChecked()) {
             params.append(QStringLiteral("sc_threshold=0 strict_gop=1"));
         }
     } else if (vcodec.endsWith("_amf")) {
@@ -525,7 +595,7 @@ void RenderPresetDialog::slotUpdateParams() {
         /*if (ui->dualPassCheckbox->isChecked())
             setIfNotSet(p, "v2pass", 1);
             */
-        if (fixedGop->isChecked()) {
+        if (fixedGop->isEnabled() && fixedGop->isChecked()) {
             params.append(QStringLiteral("sc_threshold=0 strict_gop=1"));
         }
     } else {
@@ -572,7 +642,7 @@ void RenderPresetDialog::slotUpdateParams() {
             break;
             }
         }
-        if (fixedGop->isChecked()) {
+        if (fixedGop->isEnabled() && fixedGop->isChecked()) {
             if (vcodec.startsWith("libvpx") || vcodec.startsWith("libaom-")) {
                 params.append(QStringLiteral("keyint_min=%1").arg(gopSpinner->value()));
             } else {
@@ -587,8 +657,12 @@ void RenderPresetDialog::slotUpdateParams() {
             setIfNotSet(p, "connection_type", "x11");
         }*/
     }
-    params.append(QStringLiteral("g=%1").arg(gopSpinner->value()));
-    params.append(QStringLiteral("bf=%1").arg(bFramesSpinner->value()));
+    if (gopSpinner->value() > 0) {
+        params.append(QStringLiteral("g=%1").arg(gopSpinner->value()));
+        if (bFramesSpinner->value() >= 0) {
+            params.append(QStringLiteral("bf=%1").arg(bFramesSpinner->value()));
+        }
+    }
 
     // audio tab
     QString acodec = aCodecCombo->currentText();
@@ -641,7 +715,7 @@ void RenderPresetDialog::slotUpdateParams() {
     QString addionalParams = additionalParams->toPlainText().simplified();
 
     QStringList removed;
-    for (auto p : m_uiParams) {
+    for (const auto &p : qAsConst(m_uiParams)) {
         QString store = addionalParams;
         if (store != addionalParams.remove(QRegularExpression(QStringLiteral("((^|\\s)%1=\\S*)").arg(p)))) {
               removed.append(p);
@@ -658,6 +732,42 @@ void RenderPresetDialog::slotUpdateParams() {
     parameters->setText(addionalParams.simplified());
 }
 
+void RenderPresetDialog::setPixelAspectRatio(int num, int den) {
+    parCombo->blockSignals(true);
+    if (num < 1) num = 1;
+    if (den < 1) den = 1;
+    int gcdV = gcd(num, den);
+    QString data = QStringLiteral("%1:%2").arg(num / gcdV).arg(den / gcdV);
+    int ix = parCombo->findData(data);
+    if (ix < 0) {
+        parCombo->addItem(QStringLiteral("%L1 (%2:%3)")
+                          .arg(double(num) / double(den), 0, 'g', 8)
+                          .arg(num / gcdV).arg(den / gcdV),
+                          data);
+        ix = parCombo->count() -1;
+    }
+    parCombo->setCurrentIndex(ix);
+    parCombo->blockSignals(false);
+}
+
+void RenderPresetDialog::updateDisplayAspectRatio() {
+    displayAspectNum->blockSignals(true);
+    displayAspectDen->blockSignals(true);
+    QStringList par = parCombo->currentData().toString().split(QStringLiteral(":"));
+    int parNum = resWidth->value();
+    int parDen = resHeight->value();
+    if (par.length() >= 2 && par.at(0).toInt() > 0 && par.at(1).toInt() > 0) {
+        parNum *= par.at(0).toInt();
+        parDen *= par.at(1).toInt();
+    }
+    int gcdV = gcd(parNum, parDen);
+    displayAspectNum->setValue(parNum / gcdV);
+    displayAspectDen->setValue(parDen / gcdV);
+    displayAspectNum->blockSignals(false);
+    displayAspectDen->blockSignals(false);
+    slotUpdateParams();
+};
+
 QString RenderPresetDialog::saveName()
 {
     return m_saveName;
