@@ -1,16 +1,16 @@
 /*
     SPDX-FileCopyrightText: 2008 Jean-Baptiste Mardelle <jb@kdenlive.org>
 
-SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "documentchecker.h"
 #include "bin/binplaylist.hpp"
+#include "bin/projectclip.h"
 #include "effects/effectsrepository.hpp"
 #include "kdenlivesettings.h"
 #include "kthumb.h"
 #include "titler/titlewidget.h"
-#include "bin/projectclip.h"
 
 #include <KMessageBox>
 #include <KRecentDirs>
@@ -24,8 +24,8 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QFontDatabase>
 #include <QStandardPaths>
 #include <QTreeWidgetItem>
-#include <utility>
 #include <kurlrequester.h>
+#include <utility>
 
 const int hashRole = Qt::UserRole;
 const int sizeRole = Qt::UserRole + 1;
@@ -54,7 +54,7 @@ DocumentChecker::DocumentChecker(QUrl url, const QDomDocument &doc)
     , m_abortSearch(false)
     , m_checkRunning(false)
 {
-    connect(this, &DocumentChecker::showScanning, [this](const QString message) {
+    connect(this, &DocumentChecker::showScanning, [this](const QString &message) {
         m_ui.infoLabel->setText(message);
         m_ui.infoLabel->setVisible(true);
     });
@@ -427,8 +427,8 @@ bool DocumentChecker::hasErrorInClips()
         }
         infoLabel.append(i18n("Missing proxies can be recreated on opening."));
         m_ui.rebuildProxies->setChecked(true);
-        connect(m_ui.rebuildProxies, &QCheckBox::stateChanged, [this] (int state) {
-            for (QDomElement e : m_missingProxies) {
+        connect(m_ui.rebuildProxies, &QCheckBox::stateChanged, this, [this] (int state) {
+            for (auto e : qAsConst(m_missingProxies)) {
                 if (state == Qt::Checked) {
                     e.setAttribute(QStringLiteral("_replaceproxy"), QStringLiteral("1"));
                 } else {
@@ -604,7 +604,7 @@ DocumentChecker::~DocumentChecker()
     delete m_dialog;
 }
 
-QString DocumentChecker::getMissingProducers(QDomElement e, QDomNodeList entries, QStringList verifiedPaths, QStringList missingPaths, const QStringList serviceToCheck, const QString root, const QString storageFolder)
+QString DocumentChecker::getMissingProducers(const QDomElement &e, const QDomNodeList &entries, const QStringList &verifiedPaths, QStringList missingPaths, const QStringList &serviceToCheck, const QString &root, const QString &storageFolder)
 {
     QString service = Xml::getXmlProperty(e, QStringLiteral("mlt_service"));
     if (!service.startsWith(QLatin1String("avformat")) && !serviceToCheck.contains(service)) {
@@ -859,7 +859,7 @@ void DocumentChecker::slotCheckClips()
         m_abortSearch = false;
         m_checkRunning = true;
         QString clipFolder = m_url.adjusted(QUrl::RemoveFilename).toLocalFile();
-        const QString newpath = QFileDialog::getExistingDirectory(qApp->activeWindow(), i18n("Clips folder"), clipFolder);
+        const QString newpath = QFileDialog::getExistingDirectory(qApp->activeWindow(), i18nc("@title:window", "Clips Folder"), clipFolder);
         if (newpath.isEmpty()) {
             m_checkRunning = false;
             return;
@@ -1207,7 +1207,7 @@ void DocumentChecker::slotEditItem(QTreeWidgetItem *item, int)
     }
 }
 
-void DocumentChecker::fixMissingSource(const QString &id, QDomNodeList producers)
+void DocumentChecker::fixMissingSource(const QString &id, const QDomNodeList &producers)
 {
     QDomElement e;
     for (int i = 0; i < producers.count(); ++i) {
@@ -1228,9 +1228,6 @@ void DocumentChecker::acceptDialog()
     // prepare transitions
     QDomNodeList trans = m_doc.elementsByTagName(QStringLiteral("transition"));
 
-    // prepare filters
-    QDomNodeList filters = m_doc.elementsByTagName(QStringLiteral("filter"));
-
     // Mark document as modified
     m_doc.documentElement().setAttribute(QStringLiteral("modified"), 1);
 
@@ -1418,7 +1415,6 @@ void DocumentChecker::fixClipItem(QTreeWidgetItem *child, const QDomNodeList &pr
                 // Fix clip
                 setProperty(e, QStringLiteral("_placeholder"), QStringLiteral("1"));
                 setProperty(e, QStringLiteral("kdenlive:orig_service"), getProperty(e, QStringLiteral("mlt_service")));
-                break;
             }
         }
     } else if (child->data(0, statusRole).toInt() == LUMAOK) {
