@@ -56,8 +56,8 @@
 
 using namespace Mlt;
 
-GLWidget::GLWidget(int id, QObject *parent)
-    : QQuickView(static_cast<QWindow *>(parent))
+GLWidget::GLWidget(int id, QWidget *parent)
+    : QQuickWidget(parent)
     , sendFrameForAnalysis(false)
     , m_glslManager(nullptr)
     , m_consumer(nullptr)
@@ -69,6 +69,7 @@ GLWidget::GLWidget(int id, QObject *parent)
     , m_initSem(0)
     , m_analyseSem(1)
     , m_isInitialized(false)
+    , m_maxProducerPosition(0)
     , m_threadStartEvent(nullptr)
     , m_threadStopEvent(nullptr)
     , m_threadCreateEvent(nullptr)
@@ -102,6 +103,7 @@ GLWidget::GLWidget(int id, QObject *parent)
     m_texture[0] = m_texture[1] = m_texture[2] = 0;
     qRegisterMetaType<Mlt::Frame>("Mlt::Frame");
     qRegisterMetaType<SharedFrame>("SharedFrame");
+    setAcceptDrops(true);
 
     if (m_id == Kdenlive::ClipMonitor && !(KdenliveSettings::displayClipMonitorInfo() & 0x01)) {
         m_rulerHeight = 0;
@@ -110,10 +112,10 @@ GLWidget::GLWidget(int id, QObject *parent)
     }
     m_displayRulerHeight = m_rulerHeight;
 
-    setPersistentOpenGLContext(true);
-    setPersistentSceneGraph(true);
-    setClearBeforeRendering(false);
-    setResizeMode(QQuickView::SizeRootObjectToView);
+    quickWindow()->setPersistentOpenGLContext(true);
+    quickWindow()->setPersistentSceneGraph(true);
+    quickWindow()->setClearBeforeRendering(false);
+    setResizeMode(QQuickWidget::SizeRootObjectToView);
     auto fmt = QOpenGLContext::globalShareContext()->format();
     fmt.setDepthBufferSize(format().depthBufferSize());
     fmt.setStencilBufferSize(format().stencilBufferSize());
@@ -132,8 +134,8 @@ GLWidget::GLWidget(int id, QObject *parent)
         disableGPUAccel();
     }
 
-    connect(this, &QQuickWindow::sceneGraphInitialized, this, &GLWidget::initializeGL, Qt::DirectConnection);
-    connect(this, &QQuickWindow::beforeRendering, this, &GLWidget::paintGL, Qt::DirectConnection);
+    connect(quickWindow(), &QQuickWindow::sceneGraphInitialized, this, &GLWidget::initializeGL, Qt::DirectConnection);
+    connect(quickWindow(), &QQuickWindow::beforeRendering, this, &GLWidget::paintGL, Qt::DirectConnection);
     //connect(pCore.get(), &Core::updateMonitorProfile, this, &GLWidget::reloadProfile);
 
     registerTimelineItems();
@@ -178,7 +180,7 @@ void GLWidget::initializeGL()
 {
     if (m_isInitialized) return;
 
-    openglContext()->makeCurrent(&m_offscreenSurface);
+    quickWindow()->openglContext()->makeCurrent(&m_offscreenSurface);
     initializeOpenGLFunctions();
 
     // C & D
@@ -189,6 +191,7 @@ void GLWidget::initializeGL()
     createShader();
 
     m_openGLSync = initGPUAccelSync();
+    quickWindow()->openglContext()->doneCurrent();
 
     // C & D
     if (m_glslManager) {
@@ -198,19 +201,19 @@ void GLWidget::initializeGL()
         // See this Qt bug for more info: https://bugreports.qt.io/browse/QTBUG-44677
         // TODO: QTBUG-44677 is closed. still applicable?
         m_shareContext = new QOpenGLContext;
-        m_shareContext->setFormat(openglContext()->format());
-        m_shareContext->setShareContext(openglContext());
+        m_shareContext->setFormat(quickWindow()->openglContext()->format());
+        m_shareContext->setShareContext(quickWindow()->openglContext());
         m_shareContext->create();
     }
 
-    m_frameRenderer = new FrameRenderer(openglContext(), &m_offscreenSurface, m_ClientWaitSync);
+    m_frameRenderer = new FrameRenderer(quickWindow()->openglContext(), &m_offscreenSurface, m_ClientWaitSync);
 
     m_frameRenderer->sendAudioForAnalysis = KdenliveSettings::monitor_audio();
 
-    openglContext()->makeCurrent(this);
-    connect(m_frameRenderer, &FrameRenderer::textureReady, this, &GLWidget::updateTexture, Qt::DirectConnection);
+    quickWindow()->openglContext()->makeCurrent(quickWindow());
     connect(m_frameRenderer, &FrameRenderer::frameDisplayed, this, &GLWidget::onFrameDisplayed, Qt::QueuedConnection);
     connect(m_frameRenderer, &FrameRenderer::frameDisplayed, this, &GLWidget::frameDisplayed, Qt::QueuedConnection);
+    connect(m_frameRenderer, &FrameRenderer::textureReady, this, &GLWidget::updateTexture, Qt::DirectConnection);
     m_initSem.release();
     m_isInitialized = true;
     QMetaObject::invokeMethod(this, "reconfigure", Qt::QueuedConnection);
@@ -257,8 +260,8 @@ void GLWidget::resizeGL(int width, int height)
 
 void GLWidget::resizeEvent(QResizeEvent *event)
 {
+    QQuickWidget::resizeEvent(event);
     resizeGL(event->size().width(), event->size().height());
-    QQuickView::resizeEvent(event);
 }
 
 void GLWidget::createGPUAccelFragmentProg()
@@ -391,7 +394,7 @@ static void uploadTextures(QOpenGLContext *context, const SharedFrame &frame, GL
 void GLWidget::clear()
 {
     stopGlsl();
-    update();
+    quickWindow()->update();
 }
 
 void GLWidget::releaseAnalyse()
@@ -402,12 +405,12 @@ void GLWidget::releaseAnalyse()
 bool GLWidget::acquireSharedFrameTextures()
 {
     // A
-    if ((m_glslManager == nullptr) && !openglContext()->supportsThreadedOpenGL()) {
+    if ((m_glslManager == nullptr) && !quickWindow()->openglContext()->supportsThreadedOpenGL()) {
         QMutexLocker locker(&m_contextSharedAccess);
         if (!m_sharedFrame.is_valid()) {
             return false;
         }
-        uploadTextures(openglContext(), m_sharedFrame, m_texture);
+        uploadTextures(quickWindow()->openglContext(), m_sharedFrame, m_texture);
     } else if (m_glslManager) {
         // C & D
         m_contextSharedAccess.lock();
@@ -472,7 +475,7 @@ void GLWidget::disableGPUAccel()
 
 bool GLWidget::onlyGLESGPUAccel() const
 {
-    return (m_glslManager != nullptr) && openglContext()->isOpenGLES();
+    return (m_glslManager != nullptr) && quickWindow()->openglContext()->isOpenGLES();
 }
 
 #if defined(Q_OS_WIN)
@@ -487,9 +490,9 @@ bool GLWidget::initGPUAccelSync()
 {
     if (!KdenliveSettings::gpu_accel()) return false;
     if (m_glslManager == nullptr) return false;
-    if (!openglContext()->hasExtension("GL_ARB_sync")) return false;
+    if (!quickWindow()->openglContext()->hasExtension("GL_ARB_sync")) return false;
 
-    m_ClientWaitSync = ClientWaitSync_fp(openglContext()->getProcAddress("glClientWaitSync"));
+    m_ClientWaitSync = ClientWaitSync_fp(quickWindow()->openglContext()->getProcAddress("glClientWaitSync"));
     if (m_ClientWaitSync) {
         return true;
     } else {
@@ -504,14 +507,14 @@ bool GLWidget::initGPUAccelSync()
 
 void GLWidget::paintGL()
 {
-    QOpenGLFunctions *f = openglContext()->functions();
-    float width = float(this->width() * devicePixelRatio());
-    float height = float(this->height() * devicePixelRatio());
+    QOpenGLFunctions *f = quickWindow()->openglContext()->functions();
+    float width = this->width() * devicePixelRatioF();
+    float height = this->height() * devicePixelRatioF();
 
     f->glDisable(GL_BLEND);
     f->glDisable(GL_DEPTH_TEST);
     f->glDepthMask(GL_FALSE);
-    f->glViewport(0, qRound(m_displayRulerHeight * devicePixelRatio() * 0.5), int(width), int(height));
+    f->glViewport(0, qRound(m_displayRulerHeight * devicePixelRatioF() * 0.5), int(width), int(height));
     check_error(f);
     f->glClearColor(float(m_bgColor.redF()), float(m_bgColor.greenF()), float(m_bgColor.blueF()), 0);
     f->glClear(GL_COLOR_BUFFER_BIT);
@@ -540,7 +543,7 @@ void GLWidget::paintGL()
     // Set model view.
     QMatrix4x4 modelView;
     if (!qFuzzyCompare(m_zoom, 1.0f)) {
-        if ((offset().x() != 0) || (offset().y() != 0)) modelView.translate(float(-offset().x() * devicePixelRatio()), float(offset().y() * devicePixelRatio()));
+        if ((offset().x() != 0) || (offset().y() != 0)) modelView.translate(-offset().x() * devicePixelRatioF(), offset().y() * devicePixelRatioF());
         modelView.scale(zoom(), zoom());
     }
     m_shader->setUniformValue(m_modelViewLocation, modelView);
@@ -548,8 +551,8 @@ void GLWidget::paintGL()
 
     // Provide vertices of triangle strip.
     QVector<QVector2D> vertices;
-    width = float(m_rect.width() * devicePixelRatio());
-    height = float(m_rect.height() * devicePixelRatio());
+    width = m_rect.width() * devicePixelRatioF();
+    height = m_rect.height() * devicePixelRatioF();
     vertices << QVector2D(-width / 2.0f, -height / 2.0f);
     vertices << QVector2D(-width / 2.0f, height / 2.0f);
     vertices << QVector2D(width / 2.0f, -height / 2.0f);
@@ -678,7 +681,7 @@ void GLWidget::refresh()
     }
 }
 
-bool GLWidget::checkFrameNumber(int pos, int offset, bool isPlaying)
+bool GLWidget::checkFrameNumber(int pos, bool isPlaying)
 {
     const double speed = m_producer->get_speed();
     m_proxy->positionFromConsumer(pos, isPlaying);
@@ -686,6 +689,8 @@ bool GLWidget::checkFrameNumber(int pos, int offset, bool isPlaying)
         if (isPlaying && pos >= m_loopOut) {
             m_consumer->purge();
             if (!m_isLoopMode) {
+                // end play zone mode
+                m_isZoneMode = false;
                 m_producer->set_speed(0);
                 m_proxy->setSpeed(0);
                 m_consumer->set("refresh", 0);
@@ -702,15 +707,14 @@ bool GLWidget::checkFrameNumber(int pos, int offset, bool isPlaying)
         }
         return true;
     } else if (isPlaying) {
-        int maxPos = m_producer->get_length() - 1 - offset;
-        if (pos > maxPos - 2 && !(speed < 0.)) {
+        if (pos > m_maxProducerPosition - 2 && !(speed < 0.)) {
             // Playing past last clip, pause
             m_producer->set_speed(0);
             m_proxy->setSpeed(0);
             m_consumer->set("refresh", 0);
             m_consumer->purge();
-            m_proxy->setPosition(qMax(0, maxPos));
-            m_producer->seek(qMax(0, maxPos));
+            m_proxy->setPosition(qMax(0, m_maxProducerPosition));
+            m_producer->seek(qMax(0, m_maxProducerPosition));
             return false;
         } else if (pos <= 0 && speed < 0.) {
             // rewinding reached 0, pause
@@ -731,9 +735,11 @@ void GLWidget::mousePressEvent(QMouseEvent *event)
     if ((rootObject() != nullptr) && rootObject()->property("captureRightClick").toBool() && !(event->modifiers() & Qt::ControlModifier) &&
         !(event->buttons() & Qt::MiddleButton)) {
         event->ignore();
-        QQuickView::mousePressEvent(event);
+        QQuickWidget::mousePressEvent(event);
         return;
     }
+    QQuickWidget::mousePressEvent(event);
+    event->accept();
     if ((event->button() & Qt::LeftButton) != 0u) {
         if ((event->modifiers() & Qt::ControlModifier) != 0u) {
             // Pan view
@@ -748,8 +754,6 @@ void GLWidget::mousePressEvent(QMouseEvent *event)
         m_panStart = event->pos();
         setCursor(Qt::ClosedHandCursor);
     }
-    QQuickView::mousePressEvent(event);
-    event->accept();
 }
 
 void GLWidget::mouseMoveEvent(QMouseEvent *event)
@@ -757,34 +761,32 @@ void GLWidget::mouseMoveEvent(QMouseEvent *event)
     if ((rootObject() != nullptr) && rootObject()->objectName() != QLatin1String("root") && !(event->modifiers() & Qt::ControlModifier) &&
         !(event->buttons() & Qt::MiddleButton)) {
         event->ignore();
-        QQuickView::mouseMoveEvent(event);
+        QQuickWidget::mouseMoveEvent(event);
         return;
     }
-    /*    if (event->modifiers() == Qt::ShiftModifier && m_producer) {
-        emit seekTo(m_producer->get_length() *  event->x() / width());
+    QQuickWidget::mouseMoveEvent(event);
+    if (!(event->buttons() & Qt::LeftButton)) {
+        event->accept();
         return;
-    }*/
-    QQuickView::mouseMoveEvent(event);
+    }
     if (!m_panStart.isNull()) {
         emit panView(m_panStart - event->pos());
         m_panStart = event->pos();
         event->accept();
-        QQuickView::mouseMoveEvent(event);
-        return;
-    }
-    if (!(event->buttons() & Qt::LeftButton)) {
-        QQuickView::mouseMoveEvent(event);
         return;
     }
+
     if (!event->isAccepted() && !m_dragStart.isNull() && (event->pos() - m_dragStart).manhattanLength() >= QApplication::startDragDistance()) {
         m_dragStart = QPoint();
         emit startDrag();
     }
+    event->accept();
+
 }
 
 void GLWidget::keyPressEvent(QKeyEvent *event)
 {
-    QQuickView::keyPressEvent(event);
+    QQuickWidget::keyPressEvent(event);
     if (!event->isAccepted()) {
         emit passKeyEvent(event);
     }
@@ -1292,7 +1294,7 @@ void GLWidget::setZoom(float zoom)
         double scaley = rootObject()->property("scaley").toDouble() * zoomRatio;
         rootObject()->setProperty("scaley", scaley);
     }
-    update();
+    quickWindow()->update();
 }
 
 void GLWidget::onFrameDisplayed(const SharedFrame &frame)
@@ -1301,18 +1303,24 @@ void GLWidget::onFrameDisplayed(const SharedFrame &frame)
     m_sharedFrame = frame;
     m_sendFrame = sendFrameForAnalysis;
     m_contextSharedAccess.unlock();
-    update();
+    quickWindow()->update();
 }
 
 void GLWidget::mouseReleaseEvent(QMouseEvent *event)
 {
-    QQuickView::mouseReleaseEvent(event);
-    if (m_dragStart.isNull() && m_panStart.isNull() && (rootObject() != nullptr) && rootObject()->objectName() != QLatin1String("root") &&
+    QQuickWidget::mouseReleaseEvent(event);
+    /*if (m_dragStart.isNull() && m_panStart.isNull() && (rootObject() != nullptr) && rootObject()->objectName() != QLatin1String("root") &&
         !(event->modifiers() & Qt::ControlModifier)) {
-        event->ignore();
+        event->accept();
+        qDebug()<<"::::::: MOUSE RELEASED B IGNORED";
+        return;
+    }*/
+    if ((event->modifiers() & Qt::ControlModifier)) {
+        event->accept();
         return;
     }
     if (!m_dragStart.isNull() && m_panStart.isNull() && ((event->button() & Qt::LeftButton) != 0u) && !event->isAccepted()) {
+        event->accept();
         emit monitorPlay();
     }
     m_dragStart = QPoint();
@@ -1331,7 +1339,7 @@ void GLWidget::purgeCache()
 
 void GLWidget::mouseDoubleClickEvent(QMouseEvent *event)
 {
-    QQuickView::mouseDoubleClickEvent(event);
+    QQuickWidget::mouseDoubleClickEvent(event);
     if (event->isAccepted()) {
         return;
     }
@@ -1344,11 +1352,10 @@ void GLWidget::mouseDoubleClickEvent(QMouseEvent *event)
 void GLWidget::setOffsetX(int x, int max)
 {
     m_offset.setX(x);
-    emit offsetChanged();
     if (rootObject()) {
         rootObject()->setProperty("offsetx", m_zoom > 1.0f ? x - max / 2.0f + 10 * m_zoom : 0);
     }
-    update();
+    quickWindow()->update();
 }
 
 void GLWidget::setOffsetY(int y, int max)
@@ -1357,7 +1364,7 @@ void GLWidget::setOffsetY(int y, int max)
     if (rootObject()) {
         rootObject()->setProperty("offsety", m_zoom > 1.0f ? y - max / 2.0f + 10 * m_zoom : 0);
     }
-    update();
+    quickWindow()->update();
 }
 
 std::shared_ptr<Mlt::Consumer> GLWidget::consumer()
@@ -1722,6 +1729,7 @@ int GLWidget::getCurrentPos() const
 
 void GLWidget::setRulerInfo(int duration, const std::shared_ptr<MarkerListModel> &model)
 {
+    m_maxProducerPosition = duration;
     rootObject()->setProperty("duration", duration);
     if (model != nullptr) {
         // we are resetting marker/snap model, reset zone
