@@ -10,7 +10,7 @@
 
 #include "definitions.h"
 
-class QQuickView;
+class QQuickWidget;
 
 /** @class QmlManager
     @brief Manages all Qml monitor overlays
@@ -21,7 +21,7 @@ class QmlManager : public QObject
     Q_OBJECT
 
 public:
-    explicit QmlManager(QQuickView *view);
+    explicit QmlManager(QQuickWidget *view);
 
     /** @brief return current active scene type */
     MonitorSceneType sceneType() const;
@@ -31,7 +31,7 @@ public:
     void setScene(Kdenlive::MonitorId id, MonitorSceneType type, QSize profile, double profileStretch, QRect displayRect, double zoom, int duration);
 
 private:
-    QQuickView *m_view;
+    QQuickWidget *m_view;
     MonitorSceneType m_sceneType;
 
 private slots:
