@@ -59,7 +59,7 @@ public:
     QModelIndex makeClipIndexFromID(int clipId) const override;
     /** @brief Creates an index based on the ID of the compoition*/
     QModelIndex makeCompositionIndexFromID(int compoId) const override;
-    void subtitleChanged(int subId, const QVector<int> roles);
+    void subtitleChanged(int subId, const QVector<int> &roles);
     /** @brief Creates an index based on the ID of the track*/
     QModelIndex makeTrackIndexFromID(int trackId) const override;
     QModelIndex parent(const QModelIndex &index) const override;
@@ -72,7 +72,7 @@ public:
        @param text is the new track name.
     */
     Q_INVOKABLE void setTrackName(int trackId, const QString &text);
-    Q_INVOKABLE void hideTrack(int trackId, const QString state);
+    Q_INVOKABLE void hideTrack(int trackId, bool hide);
     /** @brief returns the lower video track index in timeline.
      **/
     int getFirstVideoTrackIndex() const;
