@@ -9,8 +9,8 @@
 #include "bin/projectclip.h"
 #include "bin/projectitemmodel.h"
 #include "core.h"
-#include "utils/thumbnailcache.hpp"
 #include "doc/kthumb.h"
+#include "utils/thumbnailcache.hpp"
 
 #include <QCryptographicHash>
 #include <QDebug>
@@ -80,6 +80,6 @@ QImage ThumbnailProvider::makeThumbnail(const std::shared_ptr<Mlt::Producer> &pr
     // TODO: cache these values ?
     int imageHeight = pCore->thumbProfile()->height();
     int imageWidth = pCore->thumbProfile()->width();
-    int fullWidth = int(imageHeight * pCore->getCurrentDar() + 0.5);
+    int fullWidth = qRound(imageHeight * pCore->getCurrentDar());
     return KThumb::getFrame(frame.data(), imageWidth, imageHeight, fullWidth);
 }
